DataInfo

Struct DataInfo 

pub struct DataInfo { /* private fields */ }
Information for a data. Some of it is critical for storage, such as the memory Layout, some is less important, like the name.

Implementations

Source

impl DataInfo

pub fn deafult_for<T>() -> DataInfo
where T: Data,

Create a new DataInfo for a value based on its default values.

pub fn drop_fn(&self) -> Option<unsafe fn(OwningPtr<'_>)>

Get this Data’s type-erased drop function

pub fn layout(&self) -> Layout

Get this Data’s memory layout

pub fn name(&self) -> &'static str

Get this Data’s name

pub fn new( name: &'static str, layout: Layout, drop_fn: Option<unsafe fn(OwningPtr<'_>)>, ) -> DataInfo

Create a raw and unchekced DataInfo.