World

Struct World 

pub struct World { /* private fields */ }
This type stores everything that is offered by this crate. It is the main type of the ECS. It exposes the API for the ECS, it is the bedrock of the engine.

Implementations

Source

impl World

pub fn with_tags(tagf: TagFactory) -> World

Create a new empty World (just like World::default), but with a custom tag factory (instead of an empty one). This is useful because you can’t change the tag factory after assigning it to the world.

Source

impl World

pub fn get_tag_tracker(&self, entity: EntityId) -> TagTracker

Get the TagTracker of an entity.

Source

impl World

pub fn query<Q>(&mut self) -> impl Iterator<Item = <Q as ArchQuery>::Item<'_>>
where Q: ArchQuery,

Query the world for components.

pub fn query_filtered<'a, Q, F>( &'a mut self, ) -> impl Iterator<Item = <Q as ArchQuery>::Item<'a>> + 'a
where Q: ArchQuery + 'a, F: ArchFilter + 'a,

Query the world for components, with a filter.

Source

impl World

pub fn spawn<B>(&mut self, bundle: B) -> EntityId
where B: Bundle + Archetype,

Spawn a new entity with a bundle of components.

pub fn get_component<C>(&self, entity: EntityId) -> Option<&C>
where C: Component,

Get a reference to a Component of an entity.

pub fn get_component_mut<C>(&mut self, entity: EntityId) -> Option<&mut C>
where C: Component,

Get a mutable reference to a Component of an entity.

pub fn despawn(&mut self, entity: EntityId)

Despawn an entity from the World.