pub struct DataInfo { /* private fields */ }Expand description
Information for a data. Some of it is critical for storage, such as the memory Layout, some is less important, like the name.
Implementations